@@ -1,4 +1,4 @@
-# import cv2
+
 from random import  random
 from os import startfile
 from xingyunlib.code import md5
@@ -7,6 +7,7 @@ cache=[]
 def send_name():return md5(md5(__name__)+str(random()))
 
 def show_cv(image):
+	import cv2
 	z = send_name() + ".png"
 	cv2.imwrite(z,image)
 	startfile(z)
