@@ -105,7 +105,45 @@ class Show_text(tk.Text):
 
 
 
+def center(root):
+	# root=tk.Tk()
+	root.update()
+
+	sw = root.winfo_screenwidth()
+
+	sh = root.winfo_screenheight()
+
+	ww = root.winfo_width()
+
+	wh = root.winfo_height()
+
+	x = (sw - ww) / 2
+
+	y = (sh - wh) / 2
+
+	root.geometry("%dx%d+%d+%d" % (ww, wh, x, y))
+
+def jitter(root,times=3):
+	# root = tk.Tk()
+	import time
 
 
-
-
+	root.update()
+	root.focus_get()
+	root.attributes('-topmost', True)
+	time.sleep(0.1)
+	ww = root.winfo_width()
+	wh = root.winfo_height()
+	wx = root.winfo_x()
+	wy = root.winfo_x()
+	for x in range(times):
+		for y in (1, 2, 3, 4):
+			root.update()
+			if y == 1: wx += 10
+			if y == 2: wy += 10
+			if y == 3: wx -= 10
+			if y == 4: wy -= 10
+			root.geometry("%dx%d+%d+%d" % (ww, wh, wx, wy))
+			time.sleep(0.05)
+	root.attributes('-topmost', False)
+	return True
